MergeResult

Enum MergeResult 

pub enum MergeResult<Action: Sized> {
    CancelsOut,
    Unmergable,
    Overwrites,
    Merged(Action),
}
The result of trying to merge two actions.

Variants



CancelsOut

The action cancels out the effect of the previous action.



Unmergable

The actions cannot be merged.



Overwrites

The action fully overwrites the whole state. In this case, it does not matter how the previous action influenced the state. It is overwritten anyway.



Merged(Action)

The actions are merged into one action.